// This file is part of The New Aspell
// Copyright (C) 2001-2003 by Kevin Atkinson under the GNU LGPL license
// version 2.0 or 2.1.  You should have received a copy of the LGPL
// license along with this library if you did not you can find
// it at http://www.gnu.org/.

#ifndef ASPELL_CHAR_VECTOR__HPP
#define ASPELL_CHAR_VECTOR__HPP

#include "string.hpp"
#include "ostream.hpp"

namespace aspell
{
  typedef String CharVector;
}

#endif
